# Building a Movie Collection Manager - Full Stack Workshop with Rust, Actix, SQLx, Dioxus, and Shuttle
<center>
<img src="./docs/src/assets/workshop.jpg" />
</center>

Welcome to the this workshop! In this hands-on workshop, we will guide you through the process of building a full stack application using Rust for the API, Actix-Web as the web framework, SQLx for database connectivity, Dioxus for the front-end, and Shuttle for deployment. This workshop assumes that you have a basic understanding of Rust and its syntax.

Throughout the workshop, you will learn how to set up a Rust project with Actix-Web, implement CRUD operations for movies, establish database connectivity with PostgreSQL using SQLx, design a responsive front-end with Dioxus, and deploy the application to a hosting environment using Shuttle.

By the end of the workshop, you will have built a functional movie collection manager application. You will understand how to create APIs with Actix-Web, work with databases using SQLx, design and develop the front-end with Dioxus, and deploy the application using Shuttle. This workshop will provide you with practical experience and insights into building full stack applications with Rust.

## Prerequisites:

- Basic knowledge of the Rust programming language
- Familiarity with HTML, CSS, and JavaScript is helpful but not required

**Workshop Duration: 2 hours**

## Workshop schedule

```txt
1. Building the API with Actix (35 minutes)
  - Creating a new Rust project
  - Setting up an API using the Actix-Web framework
  - Implementing CRUD operations for movies
  - Establishing database connectivity with PostgreSQL using SQLx

2. Designing the Front-End with Dioxus (25 minutes)
  - Introduction to Dioxus and its features
  - Setting up a Dioxus project
  - Creating responsive UI components for movie listing
  - Implementing data fetching and rendering

3. Adding CRUD Functionality to the Front-End (20 minutes)
  - Implementing add, update, and delete operations for movies in the front-end
  - Connecting API endpoints with front-end components
  - Updating the UI based on API data changes

4. Deployment with Shuttle (20 minutes)
  - Introduction to Shuttle for deployment
  - Configuring deployment settings
  - Preparing the application for production
  - Deploying the API and front-end using Shuttle

5. Search and Filters (15 minutes)
  - Implementing search functionality based on movie titles, directors, genres, or release years
  - Applying filters to refine movie listings
  - Updating the UI dynamically based on search and filter criteria
    
6. Q&A and Wrap-up (15 minutes)
  - Answering participant questions
  - Sharing additional resources and learning materials
  - Recap of key takeaways and next steps

```

> *Note*: The revised workshop schedule incorporates deployment with Shuttle, allowing participants to learn how to prepare and deploy the application to a hosting environment. Please note that the durations mentioned are approximate and can be adjusted based on the pace of the workshop and the depth of coverage desired. Feel free to allocate more or less time to each section based on your priorities and the participants' requirements.

## Repository Structure:

```bash
├── api            # Rust API code
├── front          # Dioxus front-end code
└── README.md      # Workshop instructions and guidance
```

## Workshop Instructions:

Follow the step-by-step instructions provided in [Docs of this project]() to build the movie collection manager application.

The [Docs of this project]() will guide you through setting up the API with Actix-Web, establishing database connectivity with SQLx, designing the front-end with Dioxus, and deploying the application using Shuttle.

Each section of the workshop will provide code snippets and explanations to help you understand the concepts and implement the features.

Feel free to explore and customize the application further based on your own ideas and requirements.

## Resources:

- Rust: https://www.rust-lang.org/
- Actix-Web: https://actix.rs/
- SQLx: https://github.com/launchbadge/sqlx
- Dioxus: https://dioxuslabs.com/
- Shuttle: https://www.shuttle.rs/

We hope you enjoy the workshop and gain valuable insights into building full stack applications with Rust, Actix, SQLx, Dioxus, and Shuttle. If you have any questions or need assistance, please don't hesitate to ask during the workshop. Happy coding!


